aerosoltools.loaders.Load_OPCN3_file — aerosoltools 0.1.0 documentation

# aerosoltools.loaders.Load_OPCN3_file

aerosoltools.loaders.Load_OPCN3_file(file, extra_data=False)

  Load and format data from a CSV file generated by the OPC-N3 particle sensor.

  ## Parameters

  filestr

    Path to the OPCN3 CSV export file.

  extra_databool, optional

    If True, retains non-bin data in .extra_data attribute. Default is False.

  ## Returns

  OPCNAerosol2D

    Object containing: - Time-resolved particle number concentrations per bin (in cm⁻³) - Metadata including bin edges, serial number, instrument type, etc.

  Parameters:

    - file (str)

    - extra_data (bool)

  Return type:

    Aerosol2D